=== modified file 'grackle/server/tests/test_model.py'
--- grackle/server/tests/test_model.py	2012-01-22 08:34:06 +0000
+++ grackle/server/tests/test_model.py	2012-01-22 09:40:20 +0000
@@ -16,10 +16,22 @@
 
 __metaclass__ = type
 
+import datetime
+import time
+import unittest
+
+from dateutil.tz import (
+    tzoffset,
+    tzutc,
+    )
 import fixtures
+from pycassa.util import convert_uuid_to_time
 
 from grackle.server.testing.cassandra import TemporaryDB
-from grackle.server.model import CassandraConnection
+from grackle.server.model import (
+    CassandraConnection,
+    _parse_message,
+    )
 
 
 TEST_MESSAGE = """\
@@ -33,24 +45,50 @@
 """
 
 
-class TestModel(fixtures.TestWithFixtures):
-
-    def test_add_message(self):
-        keyspace = self.useFixture(TemporaryDB()).keyspace
-        c = CassandraConnection(keyspace, ['localhost:9160'])
-        c.add_message('foo', TEST_MESSAGE)
-
-
-class TestModel(fixtures.TestWithFixtures):
-
-    def test_add_message(self):
-        keyspace = self.useFixture(TemporaryDB()).keyspace
-        c = CassandraConnection(keyspace, ['localhost:9160'])
+class TestParseMessage(unittest.TestCase):
+
+    def test_works(self):
+        # _parse_message extracts interesting fields. It also parses the
+        # date and returns it separately.
+        date, msg = _parse_message(TEST_MESSAGE)
+        self.assertEqual('sysadmin@example.com', msg['from'])
+        self.assertEqual('developer@example.com', msg['to'])
+        self.assertEqual('Everything is broken', msg['subject'])
+        self.assertEqual('2000-01-01T11:02:34+11:00', msg['date'])
+        self.assertEqual('<aaaaaaaaaaaaa@example.com>', msg['message-id'])
+        self.assertEqual(
+            datetime.datetime(
+                2000, 1, 1, 11, 2, 34, tzinfo=tzoffset('', 39600)),
+            date)
+
+
+class TestCassandra(fixtures.TestWithFixtures):
+
+    def test_add_message(self):
+        keyspace = self.useFixture(TemporaryDB()).keyspace
+        c = CassandraConnection(keyspace, ['localhost:9160'])
+
+        # Write the message out to Cassandra, and read it back in.
         key = c.add_message('foo', TEST_MESSAGE)
         cmsg = c.messages.get(key)
+
+        # The archive should contain a single message, a reference to
+        # our new key.
+        archive_messages = c.archive_messages.get('foo').items()
+        self.assertEqual(1, len(archive_messages))
+        self.assertEqual(key, archive_messages[0][1])
+
+        # The key in archive_message is a TimeUUID for the Date field in
+        # the message.
+        utctime = time.mktime(datetime.datetime(
+            2000, 1, 1, 0, 2, 34, tzinfo=tzutc()).timetuple())
+        self.assertEqual(
+            utctime,
+            convert_uuid_to_time(archive_messages[0][0]))
+
+        # The stored message contains the full original text of the
+        # message, as well as interesting fields parsed out.
         self.assertEqual(TEST_MESSAGE, cmsg['content'])
-        self.assertEqual('sysadmin@example.com', cmsg['from'])
-        self.assertEqual('developer@example.com', cmsg['to'])
-        self.assertEqual('Everything is broken', cmsg['subject'])
-        self.assertEqual('2000-01-01T11:02:34+11:00', cmsg['date'])
-        self.assertEqual('<aaaaaaaaaaaaa@example.com>', cmsg['message-id'])
+        parsed_message = _parse_message(TEST_MESSAGE)[1]
+        for key, value in parsed_message.iteritems():
+            self.assertEqual(value, cmsg[key])

